@@ -1,6 +1,6 @@
 /*****************************************************************************
  * mainwindow.cpp - QStarDict, a StarDict clone written with using Qt        *
- * Copyright (C) 2007 Alexander Rodin                                        *
+ * Copyright (C) 2007-2009 Alexander                                         *
  *                                                                           *
  * This program is free software; you can redistribute it and/or modify      *
  * it under the terms of the GNU General Public License as published by      *
@@ -21,6 +21,7 @@
 
 #include <QApplication>
 #include <QCloseEvent>
+#include <QDesktopServices>
 #include <QDir>
 #include <QFile>
 #include <QFileDialog>
@@ -36,6 +37,7 @@
 #include "application.h"
 #include "popupwindow.h"
 #include "settingsdialog.h"
+#include "trayicon.h"
 
 namespace QStarDict 
 {
@@ -47,9 +49,16 @@ MainWindow::MainWindow(QWidget *parent)
     m_dict = 0;
     translationView->setDict(m_dict);
 
+    QFont font;
+    font.setPointSize(16);
+
     menu_File->insertActions(actionQuit, translationView->toolBar()->actions());
 
-    menu_Options->insertAction(menu_Options->actions().first(), wordsListDock->toggleViewAction());
+    QAction *actionWordsListDock = wordsListDock->toggleViewAction();
+    menu_Options->insertAction(menu_Options->actions().first(), actionWordsListDock);
+    actionWordsListDock->setFont(font);
+    wordsList->setProperty("FingerScrollable", true);
+    translationView->setProperty("FingerScrollable", true);
     createConnections();
 
     loadSettings();
@@ -90,6 +99,10 @@ void MainWindow::loadSettings()
     restoreGeometry(config.value("MainWindow/geometry", QByteArray()).toByteArray());
     restoreState(config.value("MainWindow/state", QByteArray()).toByteArray());
     setVisible(config.value("MainWindow/visible", true).toBool());
+    #ifndef MAEMO
+    if (isHidden() && ! Application::instance()->trayIcon()->isVisible())
+        show();
+    #endif // MAEMO
     wordsListDock->setFloating(config.value("MainWindow/wordsListDock/floating", wordsListDock->isFloating()).toBool());
     wordsListDock->setGeometry(config.value("MainWindow/wordsListDock/geometry", wordsListDock->geometry()).toRect());
     setInstantSearch(config.value("MainWindow/instantSearch", true).toBool());
@@ -113,8 +126,10 @@ void MainWindow::on_actionAbout_triggered()
     QMessageBox::about(this,
             tr("About QStarDict"),
             tr("<b>QStarDict %1 </b> - Qt version of StarDict<br>").arg(QSTARDICT_VERSION) +
-            tr("Copyright (C) 2007 Alexander Rodin "
-               "<a href=\"http://qstardict.ylsoftware.com\">http://qstardict.ylsoftware.com</a>"));
+            tr("Copyright (C) 2007-2009 Alexander Rodin "
+               "<a href=\"http://qstardict.ylsoftware.com\">http://qstardict.ylsoftware.com</a><br>"
+               "Package by SR<br>"
+               "<a href=\"http://sr.uz\">http://sr.uz</a>"));
 }
 
 void MainWindow::on_actionSettings_triggered()
@@ -123,6 +138,11 @@ void MainWindow::on_actionSettings_triggered()
     dialog.exec();
 }
 
+void MainWindow::on_actionHelp_triggered()
+{
+    QDesktopServices::openUrl(QUrl("http://wiki.qstardict.ylsoftware.com"));
+}
+
 void MainWindow::on_queryButton_clicked()
 {
     if (searchBox->text().simplified().isEmpty())
@@ -165,10 +185,12 @@ void MainWindow::timerEvent(QTimerEvent *event)
 
 void MainWindow::wordTranslated(const QString &word)
 {
+    #ifndef MAEMO
     if (word.simplified().isEmpty())
         setWindowTitle(tr("QStarDict"));
     else
         setWindowTitle(tr("%1 - QStarDict").arg(word));
+    #endif // MAEMO
     if (m_queryTimer)
     {
         killTimer(m_queryTimer);
@@ -180,7 +202,9 @@ void MainWindow::wordsListItemActivated(QListWidgetItem *item)
 {
     searchBox->setText(item->text());
     translationView->translate(item->text());
+    #ifndef MAEMO
     setWindowTitle(tr("%1 - QStarDict").arg(translationView->translatedWord()));
+    #endif // MAEMO
 }
 
 void MainWindow::setInstantSearch(bool instantSearch)
@@ -210,11 +234,26 @@ void MainWindow::keyPressEvent(QKeyEvent *event)
             searchBox->setFocus(Qt::OtherFocusReason);
         }
         if (event->key() == Qt::Key_Escape)
-            searchBox->clear();
+        {
+            if (searchBox->text().isEmpty())
+                close();
+            else
+                searchBox->clear();
+        }
     }
     QMainWindow::keyPressEvent(event);
 }
 
+void MainWindow::closeEvent(QCloseEvent *event)
+{
+    #ifndef MAEMO
+    if (! Application::instance()->trayIcon()->isVisible())
+        Application::instance()->quit();
+    #endif // MAEMO
+
+    QMainWindow::closeEvent(event);
+}
+
 }
 
 // vim: tabstop=4 softtabstop=4 shiftwidth=4 expandtab cindent textwidth=120 formatoptions=tc
